import 'package:flutter/material.dart';
import 'package:unit2/model/profile/basic_information/identification_information.dart';
import 'package:unit2/theme-data.dart/box_shadow.dart';
import 'package:unit2/theme-data.dart/colors.dart';
import 'package:unit2/utils/global.dart';
import 'package:unit2/utils/text_container.dart';

class IdentificationsScreen extends StatefulWidget {
  final List<Identification> identities;
  const IdentificationsScreen({super.key, required this.identities});

  @override
  State<IdentificationsScreen> createState() =>
      _IdentificationsScreenState();
}

class _IdentificationsScreenState
    extends State<IdentificationsScreen> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text(identificationScreenTitle),
        centerTitle: true,
        backgroundColor: primary,
      ),
      body: ListView.builder(
          padding: const EdgeInsets.symmetric(vertical: 8, horizontal: 10),
          itemCount: widget.identities.length,
          itemBuilder: (BuildContext context, int index) {
            String agency = widget.identities[index].agency!.name!;
            String idNumber =  widget.identities[index].identificationNumber!;
            bool government =  widget.identities[index].agency!.privateEntity!;
            String issuedAt =   "${widget.identities[index].issuedAt!.cityMunicipality!.description!} ${widget.identities[index].issuedAt!.cityMunicipality!.province!.description}";
            return Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Container(
                  width: screenWidth,
                  decoration: box1(),
                  padding:
                      const EdgeInsets.symmetric(horizontal: 12, vertical: 8),
                  child: Row(
                    children: [
                      Expanded(
                        child: Column(
                            mainAxisAlignment: MainAxisAlignment.start,
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Text(agency,style: Theme.of(context).textTheme.titleMedium!.copyWith(fontWeight: FontWeight.w500)),
                              const Divider(),
                              const SizedBox(height: 5,),
                              Row(
                                children: [
                                  Expanded(
                                    child: Text(
                                      "$idNumberText : $idNumber",style: Theme.of(context).textTheme.titleSmall,
                                      ),
                                  ),
                               
                                  Badge(
                            
                                      backgroundColor: success2,
                                      label: Text(
                                       government ==
                                                true
                                            ? privateText.toUpperCase()
                                            :governmentText.toUpperCase(),
                                      style: Theme.of(context).textTheme.bodySmall!.copyWith(color: Colors.white),)),
                                ],
                              ),
                              const SizedBox(height: 5,),
                              Text(issuedAt),
                            ]),
                      ),
                      IconButton(
                          onPressed: () {}, icon: const Icon(Icons.more_vert,color: Colors.grey,))
                    ],
                  ),
                ),
                const SizedBox(
                  height: 5,
                ),
              ],
            );
          }),
    );
  }
}
