import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:unit2/model/profile/work_history.dart';
import 'package:unit2/theme-data.dart/box_shadow.dart';
import 'package:unit2/theme-data.dart/colors.dart';
import 'package:unit2/utils/text_container.dart';

import '../../../utils/global.dart';

class WorkHistoryScreen extends StatefulWidget {
  final List<WorkHistory> workExperiences;
  const WorkHistoryScreen({super.key, required this.workExperiences});

  @override
  State<WorkHistoryScreen> createState() => _WorkHistoryScreenState();
}

class _WorkHistoryScreenState extends State<WorkHistoryScreen> {
  DateFormat dteFormat2 = DateFormat.yMMMMd('en_US');
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text(workHistoryScreenTitle),
        backgroundColor: primary,
        centerTitle: true,
      ),
      body: ListView.builder(
          padding: const EdgeInsets.symmetric(vertical: 8, horizontal: 10),
          itemCount: widget.workExperiences.length,
          itemBuilder: (BuildContext context, int index) {
        String position = widget.workExperiences[index].position!.title!;
        String agency = widget.workExperiences[index].agency!.name!;
        String from =
            dteFormat2.format(widget.workExperiences[index].fromDate!);
        String? to = widget.workExperiences[index].toDate == null
            ? present.toUpperCase()
            : dteFormat2.format(widget.workExperiences[index].toDate!);
        return Column(
   
          children: [
            Container(
              width: screenWidth,
              decoration: box1(),
              padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 8),
              child: Row(children: [
                Expanded(
                    child: Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text(position,style: Theme.of(context).textTheme.titleMedium!.copyWith(fontWeight: FontWeight.w600),),
                   const Divider(),
                    const SizedBox(height: 8,),
                    Text(agency,style: Theme.of(context).textTheme.titleSmall!.copyWith(fontWeight: FontWeight.w500),),
                    const SizedBox(height: 5,),
                    Text("$from to $to",style: Theme.of(context).textTheme.bodyMedium,),
                  ],
                )),
                IconButton(onPressed: () {}, icon: const Icon(Icons.more_vert,color: Colors.grey,))
              ]),
            ),
            const SizedBox(
              height: 5,
            ),
          ],
        );
      }),
    );
  }
}
